# The American Journal of Sports Medicine

[http://ajs.sagepub.com/](http://ajs.sagepub.com/)

**Correlation of Glenohumeral Internal Rotation Deficit and Total Rotational Motion to Shoulder Injuries**
**in Professional Baseball Pitchers**
Kevin E. Wilk, Leonard C. Macrina, Glenn S. Fleisig, Ronald Porterfield, Charles D. Simpson II, Paul Harker, Nick
Paparesta and James R. Andrews
_Am J Sports Med_ 2011 39: 329 originally published online December 4, 2010
DOI: 10.1177/0363546510384223

The online version of this article can be found at:
[http://ajs.sagepub.com/content/39/2/329](http://ajs.sagepub.com/content/39/2/329)

Published by:

[http://www.sagepublications.com](http://www.sagepublications.com)

On behalf of:

[American Orthopaedic Society for Sports Medicine](http://www.sportsmed.org)

**Additional services and information for** _**The American Journal of Sports Medicine**_ **can be found at:**

**Email Alerts:** [http://ajs.sagepub.com/cgi/alerts](http://ajs.sagepub.com/cgi/alerts)

**Subscriptions:** [http://ajs.sagepub.com/subscriptions](http://ajs.sagepub.com/subscriptions)

**Reprints:** [http://www.sagepub.com/journalsReprints.nav](http://www.sagepub.com/journalsReprints.nav)

**Permissions:** [http://www.sagepub.com/journalsPermissions.nav](http://www.sagepub.com/journalsPermissions.nav)

[>> Version of Record - Feb 7, 2011](http://ajs.sagepub.com/content/39/2/329.full.pdf)

[OnlineFirst Version of Record](http://ajs.sagepub.com/content/early/2010/12/04/0363546510384223.full.pdf)                   - Dec 4, 2010

[What is This?](http://online.sagepub.com/site/sphelp/vorhelp.xhtml)

**[Downloaded from ajs.sagepub.com](http://ajs.sagepub.com/)** **at GEORGIAN COURT UNIV on April 26, 2015**

## Correlation of Glenohumeral Internal Rotation Deficit and Total Rotational Motion to Shoulder Injuries in Professional Baseball Pitchers

Kevin E. Wilk,\* \[yz\] DPT, PT, Leonard C. Macrina, \[yz\] MSPT, SCS, CSCS, Glenn S. Fleisig, \[z\] PhD,
Ronald Porterfield, \[§\] MS, ATC, Charles D. Simpson II, \[y\] DPT, CSCS, Paul Harker, \[§\] ATC,
Nick Paparesta, \[§\] ATC, and James R. Andrews, \[z\] MD
Investigation performed at Champion Sports Medicine, American Sports Medicine Institute,
Birmingham, Alabama. Data collection conducted at the training facility of the Tampa Bay Rays
baseball team

Background: Glenohumeral internal rotation deficit (GIRD) indicates a 20� or greater loss of internal rotation of the throwing
shoulder compared with the nondominant shoulder.

Purpose: To determine whether GIRD and a deficit in total rotational motion (external rotation 1 internal rotation) compared with
the nonthrowing shoulder correlate with shoulder injuries in professional baseball pitchers.

Study Design: Case series; Level of evidence, 4.

Methods: Over 3 competitive seasons (2005 to 2007), passive range of motion measurements were evaluated on the dominant and
nondominant shoulders for 170 pitcher-seasons. This included 122 professional pitchers during the 3 seasons of data collection, in
which some pitchers were measured during multiple seasons. Ranges of motion were measured with a bubble goniometer during
the preseason, by the same examiner each year. External and internal rotation of the glenohumeral joint was assessed with the participant supine and the arm abducted 90� in the plane of the scapula, with the scapula stabilized anteriorly at the coracoid process.
The reproducibility of the test methods had an intraclass correlation coefficient of .81. Days in which the player was unable to participate because of injury or surgery were recorded during the season by the medical staff of the team and defined as an injury.

Results: Pitchers with GIRD (n = 40) were nearly twice as likely to be injured as those without but without statistical significance
(P = .17). Pitchers with total rotational motion deficit greater than 5� had a higher rate of injury. Minor league pitchers were more
likely than major league pitchers to be injured. However, when players were injured, major league pitchers missed a significantly
greater number of games than minor league pitchers.

Conclusion: Compared with pitchers without GIRD, pitchers with GIRD appear to be at a higher risk for injury and shoulder surgery.

Keywords: prevention; range of motion; overuse injuries; overhead athlete

The overhead throwing motion generates tremendous
demands on the glenohumeral joint at excessively high
angular velocities. Shoulder internal rotation (IR) during

\*Address correspondence to Kevin E. Wilk, DPT, PT, Champion
Sports Medicine, 805 St Vincent’s Drive, Suite G100, Birmingham, AL
35205 (e-mail: <KWilkpt@hotmail.com>).
yChampion Sports Medicine, Birmingham, Alabama.
zAmerican Sports Medicine Institute, Birmingham, Alabama.
§Tampa Bay Rays, St Petersburg, Florida.
Presented at the 34th annual meeting of the AOSSM, Orlando, Florida, July 2008.
The authors declared that they had no conflicts of interest in their
authorship and publication of this contribution.

The American Journal of Sports Medicine, Vol. 39, No. 2
DOI: 10.1177/0363546510384223
� 2011 The Author(s)

a pitch is the fastest human movement recorded, and it
occurs in excess of 7250 degrees per second. \[12,13\] The shoulder torque generated is approximately 60 N�m near the
instant of maximal external rotation (ER). From repetition
of this torque, the typical pitcher exhibits an excessive
amount of ER of the glenohumeral joint. These repetitive
torques and motions on the shoulder joint complex may contribute to the high injury rate in professional baseball.
Conte et al \[8\] reported that 28% of all injuries sustained to
professional baseball pitchers occurred at the shoulder joint.
McFarland and Wasik \[15\] reported that upper extremity injuries in collegiate baseball players accounted for 75% of the
time lost from the sport due to injury, with the pitcher being
the most commonly injured player (69%). The most common
injury cited was rotator cuff tendinitis. Shoulder injuries in
pitchers are more common than in position players. \[8,15\]

329

[Downloaded from ajs.sagepub.com at GEORGIAN COURT UNIV on April 26, 2015](http://ajs.sagepub.com/)

330 Wilk et al The American Journal of Sports Medicine

Figure 1. Total rotational motion concept: the assessment of external rotation (ER) and internal rotation (IR) at 90� of abduction
(ER 1 IR = total rotational motion). Greater ER and less IR is shown in (A) than in (B), but the total rotational range of motion (ER +
IR) is equal in both. Reprinted with permission from Wilk KE, Meister K, Andrews JR. Current concepts in the rehabilitation of the
overhead throwing athlete. Am J Sports Med. 2002;30(1):136-151.

The disparity between IR of the dominant and nondominant shoulder has recently received increased attention
from numerous clinicians. \[5,7,10,11,24\] This disparity, evidenced
as less IR on the throwing shoulder, has been referred to as
GIRD (glenohumeral IR deficit). GIRD, as defined by Burkhart et al, \[5\] is a loss of IR of the throwing shoulder of 20�
or more as compared with the nonthrowing shoulder. Some
clinicians have suggested GIRD as a cause of specific shoulder injuries. \[6,7\] Wilk et al \[26\] proposed the total rotational
motion (TRM) concept, where the amount of ER and IR at
90� of abduction are added and a TRM arc is determined
(Figure 1). The authors reported that the TRM in the throwing shoulders of professional baseball pitchers is within 5� of
the nonthrowing shoulder. \[26\] Furthermore, the authors suggested that a TRM arc outside the 5� range may be a contributing factor to shoulder injuries.
Although these proposed theories exist, the concepts are
based on anecdotal experience and not published scientific
data. The purpose of this study was to prospectively assess
glenohumeral joint rotational motion, the difference in
bilateral TRM, and how these factors correlate with injury
risks. The ultimate goal was to correlate the findings to
shoulder injuries in professional baseball pitchers each
year during a 3-year period within the same professional
baseball organization.

MATERIALS AND METHODS

Participants

The study was conducted over 3 competitive seasons, from
the beginning of 2005 to the end of 2007. Shoulder measurements were taken during spring training physical

TABLE 1
Participant Characteristics \[a\]

Age, y 25.6 6 4.1
No. of right-handed pitcher-seasons 126
No. of left handed pitcher-seasons 44
Years of professional experience 5.2 6 3.1
Height, cm 189.3 6 6.0
Mass, kg 91.9 6 9.9

aN = 170 pitcher-seasons.

examinations. There were 170 pitcher-seasons included—
13 pitchers had their passive range of motion (PROM)
assessed in 3 consecutive seasons; 25 pitchers had it
assessed in 2 consecutive seasons; and 81 had it assessed
only once. Thus, there were 170 total measurements taken
on the 122 pitchers who met the inclusion criteria. All participants were pain-free and asymptomatic at the time of
testing. Exclusion criteria included anyone with a prior
shoulder surgery within 2 years and any player who was
unable to participate in daily spring training activities. Of
the 170 pitcher-seasons, 126 involved right-handed pitchers
and 44 involved left-handed pitchers. The average years of
professional baseball experience was 5.2. Table 1 presents
a description of the patient characteristics.

Testing Procedure

Glenohumeral joint PROM was assessed by the same
examiners each year. Shoulder ER and IR was assessed
at 90� of abduction and in the scapular plane by 1 examiner
(K.E.W.) while another examiner (L.C.M.) measured the

[Downloaded from ajs.sagepub.com at GEORGIAN COURT UNIV on April 26, 2015](http://ajs.sagepub.com/)

Vol. 39, No. 2, 2011 Glenohumeral Internal Rotation Deficit and Total Rotational Motion 331

Figure 2. A, passive assessment of glenohumeral external rotation range of motion at 90� of abduction and 10� of horizontal
adduction (scapular plane) with a bubble goniometer. B, assessment of glenohumeral internal rotation range of motion performed
with stabilization of the scapula. The scapular coracoid process is palpated by the thumb, and the fingers are placed over the
body of the scapula posteriorly.

PROM with a bubble goniometer. During the ER and IR
PROM assessment, the scapula was stabilized by 1 examiner (Figure 2). \[18,27\] The examiner passively moved the
extremity to end range (point where end feel is perceived),
and that position was held as the goniometer was aligned
and read. For shoulder IR, a combination of end feel, palpation of the coracoid process, and visualization of compensatory movement was used to determine the end range of
motion (ROM). The extremity was rotated until the participant’s coracoid was felt rising into the examiner’s thumb;
motion was stopped when this movement occurred. To
avoid altering the normal glenohumeral arthrokinematics,
the humeral head was not manually stabilized. \[27\] The
examiner performing the PROM assessment and end feel
assessment had 25 years of clinical experience, including
19 years of experience performing spring training physicals for professional baseball players.
A standard goniometer with an attached customized
bubble inclinometer was used to ensure proper perpendicular alignment of the goniometer to the ground. For all
shoulder measurements, the axis of the goniometer was
positioned over the olecranon process, with the stationary
arm of the device perpendicular to the ground and with
the moveable arm aligned along the ulna to the ulnar styloid process. \[19,27\] All measurements were taken before any
exercise, warm-up, or throwing activities. This testing procedure was utilized in a recently published article by Wilk
et al. \[27\]

Reliability

A pilot study was previously performed to assess the intratester reliability of the goniometric methodology of this
study. Ten asymptomatic men (mean age, 28.3 years;

height, 180 cm; weight, 88 kg) were measured once in
both positions for ER and IR PROM by the same examiners
used in the current study. Both measurements were
repeated on 5 consecutive days to assess intratester reliability. The order of tests performed was randomized,
and all participants refrained from participating in any
overhead throwing activities during the testing period.
To examine the test-retest reliability, intraclass correlation coefficients were calculated on shoulder ER and shoul
der IR using data collected in the pilot study. Singlemeasure intraclass correlation results were .81 for shoulder IR and .87 for shoulder ER. Wilk et al \[27\] reported
that the highest intratester reliability for measuring IR
was with scapular stabilization, at .62, compared with .51
when humeral head stabilization was employed.

Injury Assessment and Classification

All shoulder injuries were assessed by the head athletic
trainer and the team physician (minimum of 12 years of
professional baseball experience) of each club. For the
minor league teams, the injuries were assessed, diagnosed,
and classified by the head athletic trainer and physician of
that team. The specific injuries (differential diagnosis,
days on the disabled list, days unable to compete, and surgeries) were all recorded by each team’s medical staff.
Before each game, the head athletic trainer determined
the player’s status, which was defined as able to play, limited play, or unable to play. Unable to play referred to
a player who was unable to play in that game because of
shoulder injury or shoulder pain. Limited play referred to
a player who had to leave the game because of injury.
For the purpose of this study, players unable to play and
players who experienced limited play were defined as being

[Downloaded from ajs.sagepub.com at GEORGIAN COURT UNIV on April 26, 2015](http://ajs.sagepub.com/)

332 Wilk et al The American Journal of Sports Medicine

TABLE 2
Range of Motion Comparisons \[a\]

Dominant Nondominant

External rotation, 90� 136.1 6 11.2 128.6 6 11.0
Internal rotation, 90� 47.5 6 10.6 59.1 6 11.0
Total rotational motion 183.7 6 14.5 187.7 6 14.5

aIn degrees. Each row, P \\ .001.

injured. The number of days on the disabled list was
recorded but not used for data analysis owing to the inherit
inconsistencies seen in that type of classification. If a player
left the team for any reason (trade, released, retired, etc),
every attempt was made to locate and contact that player
to determine any injury occurrence or subsequent surgery.

Study Design

Participants were determined to have exhibited GIRD if
their throwing shoulders displayed a 20� or more loss of
IR compared with their nonthrowing shoulders. In addition, anyone who had a deficit of TRM more than 5� for
his dominant shoulder (in comparison with his nondominant shoulder) was considered to exhibit a significant deficit in TRM. \[26\] The players’ IR deficit and TRM deficit
values were analyzed relative to shoulder injuries occurring in the season that followed the measurements.

Statistical Analysis

Statistical analysis was performed with SPSS 11.5 (SPSS
Inc, Chicago, IL). Ranges of motion were compared between
dominant and nondominant shoulders using paired t tests
(P \\ .05). Fisher exact tests were performed to identify
any significant associations (P \\ .05) between GIRD and
shoulder injury, and TRM deficit and shoulder injury.

RESULTS

Descriptive statistics for the 170 pitcher-seasons demonstrated average ERs (at 90� of shoulder abduction) of
136.1� 6 11.2� and 128.6� 6 11.0� on the dominant and
nondominant sides, respectively. The mean dominant IR
with the scapula stabilized was 47.5� 6 10.6�, whereas
the mean nondominant IR was 59.1� 6 11.0�. The TRM

(ie, ER 1 IR) was 183.7� 6 14.5� and 187.7� 6 14.5� on
the dominant and nondominant sides, respectively. A statistically significant difference was found between dominant and nondominant shoulders in IR, ER, and TRM
(P \\ .001) (Table 2).
During the 3 competitive seasons under study, there
were 40 pitchers with GIRD, of whom 11 developed an
injury requiring missed playing time. Also, of the 170
pitcher-seasons noted during the study, 33 injuries (30
players) resulted in a total of 1529 missed games.

Injured pitchers had a slightly higher IR deficit (12.9� 6
12.0�) than noninjured pitchers (11.3� 6 11.3�), but this difference was not significant (P = .46). Twenty-eight percent
(11 of 40) of the pitchers with GIRD were injured, whereas
17% (22 of 130) without GIRD were injured; however, this
was not statistically significant (P = .17; odds ratio = 1.9,
95% confidence interval = 0.8 to 4.0).
Thirteen percent (12 of 92) of the pitchers with TRM
deficit less than or equal to 5� were injured, whereas 27%
(21 of 78) of the pitchers with a TRM deficit greater than
5� were injured. Therefore, pitchers with a TRM difference
greater than 5� were more likely to be injured (odds ratio =
2.5, 95% confidence interval = 1.1 to 5.3; P = .03). Of the 37
injuries reported, 29 (78%) occurred in pitchers whose
dominant-arm TRM was greater than 176�; 6 injuries
(16%) occurred in pitchers whose TRM was less than
176�; and 2 pitchers (5%) sustained injuries with a TRM
of 176�.

There were no significant associations between IR difference and age (P = .504), height (P = .977), weight (P =
.460), or years of experience (P = .924). A comparison was
performed using independent-sample t tests to compare
major league to minor league pitchers. No significant difference existed between major and minor leaguers’ IR difference (P = .81) or TRM difference (P = .58). A significant
relationship between pitching level and shoulder injury
existed (P = .04). Minor league pitchers were 2.5 times
more likely to become injured (odds ratio = 2.5, 95% confidence interval = 1.1 to 5.6) than major league pitchers.
However, when injured, a major league pitcher missed
a greater number of games (P = .04). Major league pitchers
missed 68.3 6 44.6 games per injury, whereas minor
league pitchers missed only 35.2 6 44.6 games per injury.

DISCUSSION

Because of the repetition of such high forces generated during the throwing motion, the overhead throwing athlete
can exhibit numerous and significant adaptations. Some
of the most common adaptations are seen at the glenohumeral joint. Most throwers exhibit an obvious motion disparity whereby ER is excessive and IR is limited at 90� of
abduction. \[1,3,4,9,14,16,26\] The loss of IR has been reported in
the literature by numerous authors. \[||\] There have been
numerous proposed reasons for the motion adaptations,
which include osseous adaptations (retroversion) \[9,20-22\]

and soft tissue adaptations (capsular \[5,25\] and muscular \[3,23,26\] ). Reinold et al \[23\] reported that following a pitching
performance, there is a loss of glenohumeral joint IR of 9.5�
that lasts for 24 hours. Burkhart et al \[5\] suggested that
GIRD is due to posterior capsular tightness. They concluded that stretching is the most appropriate treatment
to address the IR deficit, and they recommended a posterior
capsular release, should an aggressive stretching program
not improve IR PROM. Borsa et al \[3\] documented that pitchers exhibit greater posterior translation than anterior

||References 1, 2, 4, 9, 14, 17, 21, 22, 25.

[Downloaded from ajs.sagepub.com at GEORGIAN COURT UNIV on April 26, 2015](http://ajs.sagepub.com/)

Vol. 39, No. 2, 2011 Glenohumeral Internal Rotation Deficit and Total Rotational Motion 333

TABLE 3

Risk Factors Associated With Shoulder Injury

Pitchers Who Were Injured, %

Risk Factor With Risk Factor Without Risk Factor Odds Ratio (95% Confidence Interval) P

Total rotational motion deficit greater 27 (21 of 78) 13 (12 of 92) 2.5 (1.1, 5.3) .03
than 5�

Glenohumeral internal rotation deficit 28 (11 of 40) 17 (22 of 130) 1.9 (0.8, 4.2) .17
(internal rotation deficit �20�)

Minor leaguer 27 (28 of 104) 13 (9 of 70) 2.5 (1.1, 5.6) .04

translation. Furthermore, they reported that some individuals with very small amounts of IR PROM exhibited significant posterior glenohumeral laxity on objective testing.
They proposed that the loss of IR was due to muscular
tightness and humeral head retroversion and not posterior
capsular tightness. Crockett et al \[9\] and others \[20-22\] documented greater retroversion in the throwers’ dominant
shoulders compared with their nondominant shoulders.
Thus, if the loss of IR is due to osseous adaptation and
muscular tightness, a stretching program directed toward
the posterior rotator cuff muscles appears most appropriate to treat GIRD.
In this study, pitchers exhibited greater glenohumeral
ER and less IR on the throwing side compared with the
nonthrowing side, which is consistent with previous
research. \[1,4,9,16,26\] Furthermore, the average TRM was
within 5�, as reported by Wilk et al \[26\] in a previously published article. In this study, the mean TRM of the dominant shoulder was 183.7� and on the nondominant side,
187.7�. Also in this study, the pitchers’ dominant shoulder
IR was approximately 47.5� when the scapula was stabilized. In a previous study, we reported that the IR motion
of the dominant shoulder was approximately 61�; however,
end ROM was noted when compensatory scapular motion
was detected with visual inspection only. We have found
that the most reliable method of assessing IR PROM in
the throwing shoulder occurs when the scapula is stabilized at the coracoid process.
This study also examined the relationship between (1)
age and years of experience and (2) shoulder ROM,
GIRD, and TRM. No significant correlation was noted
between age and IR difference (P = .66) or between years
of experience and IR difference (P = .87). Interestingly,
the professional baseball team that we studied represents
a young average age of the pitchers on staff. Of the 30
organizations in professional baseball, this organization
is the sixth youngest (mean age of the team, 27.9 years;
the pitching staff, 25.3 years). We wonder if the results
would change if we studied a team with the oldest mean
age (30.8 years) in Major League Baseball.
There appears to be an increasing concern regarding
the correlation between sustaining a shoulder injury and
the loss of IR and GIRD. \[5-7\] To our knowledge, this is the
first published study examining prospective PROM assessment and shoulder injuries in professional baseball

pitchers during multiple seasons. We found that pitchers
with GIRD exhibited almost twice the risk of sustaining
a shoulder injury than pitchers without GIRD.
Burkhart et al \[5\] reported that a side-to-side difference of
20� or greater resulted in greater susceptibility to injury.
In this study, we found that injured players had a mean
GIRD of 12.9�. Of 40 pitchers with GIRD, 11 were injured.
Of the 130 shoulders without GIRD, 22 were injured.
Of the pitchers with GIRD, 7% (3 of 40) underwent
arthroscopic procedures to debride the rotator cuff and glenoid labrum. None received a posterior capsular release.
Conversely, of the 130 pitcher-seasons without a case of
GIRD, only 4 players underwent a shoulder arthroscopy.
Although not included in this study, 5 players underwent
elbow surgery during this time frame (4 ulnar collateral
ligament reconstructions). Of the 5 players who had elbow
surgery, 3 had GIRD.
The TRM concept has been discussed by several
authors. \[11,16,26\] This study is the first to examine the relationship between TRM and shoulder injuries. Pitchers
whose TRM comparison was outside the 5� acceptable difference range exhibited a 2.5-times greater risk of sustaining a shoulder injury. In sum, 92 shoulders had TRM
within the 5� range, and 78 shoulders had TRM outside
the 5� range. \[26\] Furthermore, of the 37 injuries, 29 (78%)
were sustained in throwers whose TRM was greater than
176�. Stretching to increase IR PROM, thereby treating
the GIRD, may result in an increase of TRM greater
than 176� or outside the 5� acceptable window, compared
with the contralateral shoulder. We believe that this may
lead to an increased risk of injury because of the increased
demands on the dynamic and static stabilizers surrounding the shoulder joint. Further research is needed to
expose these effects on shoulder injuries. We believe that
TRM is a valuable assessment tool and an important component in PROM assessment of throwers. This should be
incorporated into the thrower’s shoulder examination to
determine if a ROM discrepancy is present in the athlete.
An analysis of shoulders that exhibited GIRD and TRM
differences was performed with respect to shoulder injury.
We found no significant relationship (P = .130) between
GIRD with TRM differences and missed games/surgeries.
Pitchers with a TRM deficit greater than the 5� window
(Table 3) were 2.5 times more likely to be injured (P =
.03). Clinically, we believe that pitchers with GIRD and

[Downloaded from ajs.sagepub.com at GEORGIAN COURT UNIV on April 26, 2015](http://ajs.sagepub.com/)

334 Wilk et al The American Journal of Sports Medicine

TRM differences outside the 5� window are at greater risk
of injury. We examined the effect of having GIRD and
a TRM deficit greater than 5� and noted only a trend (P
= .09) in which this subgroup demonstrated a 2.2 times
increased risk of injury. In this study, those clinical observations were possibly not substantiated because of the relatively low number of injuries and the total number of
players involved throughout the 3-year study. Further
research is needed to examine this relationship.
In this study, only 13 of the 40 pitchers that exhibited
GIRD were followed by the athletic training staff the following year or tracked during the time frame of this study
(2005-2007). Of the 13 who were tracked, 11 were successfully treated by the athletic training staff. We believe that
this point is important—most pitchers who exhibit GIRD
can be successfully treated for a loss of IR PROM with an
effective stretching program. To emphasize this point, we
have developed a stretching and ROM program to treat
pitchers with GIRD before they sustain an injury, in hopes
of preventing occurrence. This stretching program is part
of the pitcher’s in-season and off-season training program.
Two of 3 pitchers who exhibited GIRD in back-to-back seasons had shoulder surgery, and the third missed approximately 10% of the season because of elbow complaints. In
this study, we noted a 62% reduction in all pitchers with
GIRD from the 2006 season to the 2007 season. Furthermore, the 2007 season had the fewest injuries and the least
amount of games missed. Anecdotally, we have noticed
a reduction in GIRD in players from year to year. We
believe that this is due to the greater recognition of
GIRD as part of the spring training physical examination
and to the more effective treatment strategies. We have
incorporated this as a part of our spring training physical
examination: If a player exhibits GIRD and/or a TRM difference greater than 5�, he is placed on a supervised daily
stretching program for the remainder of the season to eliminate the GIRD PROM deficits. In addition, caution is
taken to not exceed 176� of TRM in the throwing shoulder.

Limitations of the Study

We believe that the relatively small sample size of injuries
and total pitcher-seasons throughout the 3 seasons may
have affected the overall power of the data. Also, pitchers
are often traded from one organization to another, which
makes it difficult to locate them regarding their injuries,
surgeries, or missed games. We made every attempt possible to locate every player to update his medical status. In
this study, only 36 shoulders were able to be evaluated
for 2 or more seasons, because of trades, roster changes,
and so forth. We believe that this is a significant limitation
of this study. Another concern was the classification system used to determine an injury by the athletic trainers
at each level. We relied on the team’s medical staff to accurately recognize and record the injuries. As such, players
may not report an injury, they may be misdiagnosed, or
they may not be diagnosed at all by the medical staff. We
debated on what to consider an injury. We concluded
that any pitcher missing a game because of a shoulder

complaint was considered unable to participate and thus
classified as injured. Further studies are needed to control
for these variables and thus confirm or refute our original
findings.

CONCLUSION

Based on the results, a trend may exist in professional
baseball pitchers with GIRD in that they have a higher
risk of shoulder injuries. Also, in this study, pitchers
with a TRM deficit greater than 5� had a significantly
higher injury rate that resulted in missed playing time.
The medical provider should consider these factors when
determining the long-term prognosis of the pitchers.

ACKNOWLEDGMENT

We acknowledge the contributions of Mark Vinson, ATC,
Kathleen M. Devine, DPT, MPH, Kim Suarez-Terrell,
MSPT, Cristina Brassil, MSPT, and Christopher Arrigo,
MSPT, ATC, for their extensive assistance in data collection and support. Furthermore, a special thank you to
the Tampa Bay Rays baseball organization for its total support and commitment to this project. Without it, this project would not have been possible.

REFERENCES

1. Bigliani LU, Codd TP, Connor PM, Levine WN, Littlefield MA, Hershon
   SJ. Shoulder motion and laxity in the professional baseball player.
   Am J Sports Med. 1997;25(5):609-613.

1. Borsa PA, Dover GC, Wilk KE, Reinold MM. Glenohumeral range of
   motion and stiffness in professional baseball pitchers. Med Sci
   Sports Exerc. 2006;38(1):21-26.

1. Borsa PA, Wilk KE, Jacobson JA, et al. Correlation of range of motion
   and glenohumeral translation in professional baseball pitchers. Am J
   Sports Med. 2005;33(9):1392-1399.

1. Brown LP, Niehues SL, Harrah A, Yavorsky P, Hirshman HP. Upper
   extremity range of motion and isokinetic strength of the internal
   and external shoulder rotators in major league baseball players. Am
   J Sports Med. 1988;16(6):577-585.

1. Burkhart SS, Morgan CD, Kibler WB. The disabled throwing shoulder:
   spectrum of pathology. Part I: pathoanatomy and biomechanics.
   Arthroscopy. 2003;19(4):404-420.

1. Burkhart SS, Morgan CD, Kibler WB. The disabled throwing shoulder:
   spectrum of pathology. Part II: evaluation and treatment of SLAP
   lesions in throwers. Arthroscopy. 2003;19(5):531-539.

1. Burkhart SS, Morgan CD, Kibler WB. The disabled throwing shoulder:
   spectrum of pathology. Part III: the SICK scapula, scapular dyskinesis, the kinetic chain, and rehabilitation. Arthroscopy. 2003;19(6):
   641-661.

1. Conte S, Requa RK, Garrick JG. Disability days in major league baseball. Am J Sports Med. 2001;29(4):431-436.

1. Crockett HC, Gross LB, Wilk KE, et al. Osseous adaptation and range
   of motion at the glenohumeral joint in professional baseball pitchers.
   Am J Sports Med. 2002;30(1):20-26.

1. Dines JS, Frank JB, Akerman M, Yocum LA. Glenohumeral internal
   rotation deficits in baseball players with ulnar collateral ligament
   insufficiency. Am J Sports Med. 2009;37(3):566-570.

1. Ellenbecker TS, Roetert EP, Bailie DS, Davies GJ, Brown SW. Glenohumeral joint total rotation range of motion in elite tennis players and
   baseball pitchers. Med Sci Sports Exerc. 2002;34(12):2052-2056.

[Downloaded from ajs.sagepub.com at GEORGIAN COURT UNIV on April 26, 2015](http://ajs.sagepub.com/)

Vol. 39, No. 2, 2011 Glenohumeral Internal Rotation Deficit and Total Rotational Motion 335

12. Fleisig GS, Andrews JR, Dillman CJ, Escamilla RF. Kinetics of baseball pitching with implications about injury mechanisms. Am J Sports
    Med. 1995;23(2):233-239.

01. Fleisig GS, Barrentine SW, Escamilla RF, Andrews JR. Biomechanics
    of overhand throwing with implications for injuries. Sports Med.
    1996;21(6):421-437.

01. Johnson L. Patterns of shoulder flexibility among college baseball
    players. J Athl Train. 1992;27(1):44-49.

01. McFarland EG, Wasik M. Epidemiology of collegiate baseball injuries.
    Clin J Sport Med. 1998;8(1):10-13.

01. Meister K. Injuries to the shoulder in the throwing athlete. Part one:
    Biomechanics/pathophysiology/classification of injury. Am J Sports
    Med. 2000;28(2):265-275.

01. Meister K, Day T, Horodyski M, Kaminski TW, Wasik MP, Tillman S.
    Rotational motion changes in the glenohumeral joint of the adolescent/Little League baseball player. Am J Sports Med. 2005;33(5):
    693-698.

01. Morrissey D, Morrissey MC, Driver W, King JB, Woledge RC.
    Manual landmark identification and tracking during the medial rotation test of the shoulder: an accuracy study using three-dimensional
    ultrasound and motion analysis measures. Man Ther. 2008;13(6):
    529-535.

01. Norkin C, White DJ. Measurement of Joint Motion: A Guide to
    Goniometry. 2nd ed. Philadelphia, PA: Davis; 1995.

01. Osbahr DC, Cannon DL, Speer KP. Retroversion of the humerus in
    the throwing shoulder of college baseball pitchers. Am J Sports
    Med. 2002;30(3):347-353.

01. Pieper HG. Humeral torsion in the throwing arm of handball players.
    Am J Sports Med. 1998;26(2):247-253.

01. Reagan KM, Meister K, Horodyski MB, Werner DW, Carruthers C,
    Wilk K. Humeral retroversion and its relationship to glenohumeral
    rotation in the shoulder of college baseball players. Am J Sports
    Med. 2002;30(3):354-360.

01. Reinold MM, Wilk KE, Macrina LC, et al. Changes in shoulder and
    elbow passive range of motion after pitching in professional baseball
    players. Am J Sports Med. 2008;36(3):523-527.

01. Torres RR, Gomes JL. Measurement of glenohumeral internal rotation in asymptomatic tennis players and swimmers. Am J Sports
    Med. 2009;37(5):1017-1023.

01. Tyler TF, Nicholas SJ, Roy T, Gleim GW. Quantification of posterior
    capsule tightness and motion loss in patients with shoulder impingement. Am J Sports Med. 2000;28(5):668-673.

01. Wilk KE, Meister K, Andrews JR. Current concepts in the rehabilitation of the overhead throwing athlete. Am J Sports Med.
    2002;30(1):136-151.

01. Wilk KE, Reinold MM, Macrina LC, et al. Glenohumeral internal rotation measurements differ depending on stabilization techniques.
    Sports Health. 2009;1(2):131-136.

For reprints and permission queries, please visit SAGE’s Web site at <http://www.sagepub.com/journalsPermissions.nav>

[Downloaded from ajs.sagepub.com at GEORGIAN COURT UNIV on April 26, 2015](http://ajs.sagepub.com/)
